# eric7.EricWidgets.EricCompleters

Module implementing various kinds of completers.

### Global Attributes

None

### Classes

EricDirCompleter | Class implementing a completer for directory names.
EricFileCompleter | Class implementing a completer for file names.
EricStringListCompleter | Class implementing a completer for string lists.

### Functions

None

## EricDirCompleter

Class implementing a completer for directory names.

### Derived from

QCompleter

### Class Attributes

None

### Class Methods

None

### Methods

EricDirCompleter | Constructor
rootPath | Public method to get the root path of the model.
setRootPath | Public method to set the root path of the model.

### Static Methods

None

#### EricDirCompleter (Constructor)

EricDirCompleter(parent=None, completionMode=QCompleter.CompletionMode.PopupCompletion, showHidden=False)

Constructor

parent
  parent widget of the completer (QWidget)
completionMode
  completion mode of the completer (QCompleter.CompletionMode)
showHidden
  flag indicating to show hidden entries as well (boolean)

#### EricDirCompleter.rootPath

rootPath()

Public method to get the root path of the model.

Return:
  root path of the model

Return Type:
  str

#### EricDirCompleter.setRootPath

setRootPath(path)

Public method to set the root path of the model.

path (str)
  root path for the model

Up

## EricFileCompleter

Class implementing a completer for file names.

### Derived from

QCompleter

### Class Attributes

None

### Class Methods

None

### Methods

EricFileCompleter | Constructor
rootPath | Public method to get the root path of the model.
setRootPath | Public method to set the root path of the model.

### Static Methods

None

#### EricFileCompleter (Constructor)

EricFileCompleter(parent=None, completionMode=QCompleter.CompletionMode.PopupCompletion, showHidden=False)

Constructor

parent
  parent widget of the completer (QWidget)
completionMode
  completion mode of the completer (QCompleter.CompletionMode)
showHidden
  flag indicating to show hidden entries as well (boolean)

#### EricFileCompleter.rootPath

rootPath()

Public method to get the root path of the model.

Return:
  root path of the model

Return Type:
  str

#### EricFileCompleter.setRootPath

setRootPath(path)

Public method to set the root path of the model.

path (str)
  root path for the model

Up

## EricStringListCompleter

Class implementing a completer for string lists.

### Derived from

QCompleter

### Class Attributes

None

### Class Methods

None

### Methods

EricStringListCompleter | Constructor

### Static Methods

None

#### EricStringListCompleter (Constructor)

EricStringListCompleter(parent=None, strings=None, completionMode=QCompleter.CompletionMode.PopupCompletion)

Constructor

parent
  parent widget of the completer (QWidget)
strings
  list of string to load into the completer (list of strings)
completionMode
  completion mode of the completer (QCompleter.CompletionMode)

Up